==> haskell-zeromq4-haskell-0.8.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zeromq4-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zeromq4-haskell
version:              0.8.0
visibility:           public
id:                   zeromq4-haskell-0.8.0-ABhDUvWoqR34cW3JvVjpQS
key:                  zeromq4-haskell-0.8.0-ABhDUvWoqR34cW3JvVjpQS
license:              MIT
copyright:            (c) 2010 - 2015 zeromq-haskell authors
maintainer:           Toralf Wittner <tw@dtex.org>
author:               Toralf Wittner
stability:            experimental
homepage:             https://gitlab.com/twittner/zeromq-haskell/
synopsis:             Bindings to ZeroMQ 4.x
description:
    The 0MQ lightweight messaging kernel is a library which extends
    the standard socket interfaces with features traditionally provided
    by specialised messaging middleware products.

    0MQ sockets provide an abstraction of asynchronous message queues,
    multiple messaging patterns, message filtering (subscriptions),
    seamless access to multiple transport protocols and more.

    This library provides the Haskell language binding to 0MQ >= 4.x

category:             System, FFI
abi:                  17cb331221b21d4fa4a9fad465b9d425
exposed:              True
exposed-modules:
    Data.Restricted System.ZMQ4 System.ZMQ4.Internal
    System.ZMQ4.Internal.Base System.ZMQ4.Internal.Error
    System.ZMQ4.Monadic

import-dirs:          /usr/lib/ghc-9.0.2/site-local/zeromq4-haskell-0.8.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zeromq4-haskell-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zeromq4-haskell
hs-libraries:         HSzeromq4-haskell-0.8.0-ABhDUvWoqR34cW3JvVjpQS
extra-libraries:      zmq
include-dirs:         /usr/include/pgm-5.3
depends:
    async-2.2.4-DsKZe3TE8bS5FmfUvwss6n base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 exceptions-0.10.4
    monad-control-1.0.3.1-GpgVyPHmiKkFcdIIOGrkhh transformers-0.5.6.2
    transformers-base-0.4.6-47QXFWU8OI3AOeTzeSnbjy

haddock-interfaces:
    /usr/share/doc/haskell-zeromq4-haskell/html/zeromq4-haskell.haddock

haddock-html:         /usr/share/doc/haskell-zeromq4-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zeromq4-haskell-0.8.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zeromq4-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zeromq4-haskell
version:              0.8.0
visibility:           public
id:                   zeromq4-haskell-0.8.0-6oegC4kX4taDUq1gnKg4XR
key:                  zeromq4-haskell-0.8.0-6oegC4kX4taDUq1gnKg4XR
license:              MIT
copyright:            (c) 2010 - 2015 zeromq-haskell authors
maintainer:           Toralf Wittner <tw@dtex.org>
author:               Toralf Wittner
stability:            experimental
homepage:             https://gitlab.com/twittner/zeromq-haskell/
synopsis:             Bindings to ZeroMQ 4.x
description:
    The 0MQ lightweight messaging kernel is a library which extends
    the standard socket interfaces with features traditionally provided
    by specialised messaging middleware products.

    0MQ sockets provide an abstraction of asynchronous message queues,
    multiple messaging patterns, message filtering (subscriptions),
    seamless access to multiple transport protocols and more.

    This library provides the Haskell language binding to 0MQ >= 4.x

category:             System, FFI
abi:                  cc08c743c6c05c0932b18f5592284703
exposed:              True
exposed-modules:
    Data.Restricted System.ZMQ4 System.ZMQ4.Internal
    System.ZMQ4.Internal.Base System.ZMQ4.Internal.Error
    System.ZMQ4.Monadic

import-dirs:          /usr/lib/ghc-9.0.2/site-local/zeromq4-haskell-0.8.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zeromq4-haskell-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zeromq4-haskell
hs-libraries:         HSzeromq4-haskell-0.8.0-6oegC4kX4taDUq1gnKg4XR
extra-libraries:      zmq
include-dirs:         /usr/include/pgm-5.3
depends:
    async-2.2.4-GElwEr766DP3ejURF9fDgA base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 exceptions-0.10.4
    monad-control-1.0.3.1-7lMMPCaUiEs1ejka1kSp8A transformers-0.5.6.2
    transformers-base-0.4.6-3tiuWaRh2so9DJQGvLVNGp

haddock-interfaces:
    /usr/share/doc/haskell-zeromq4-haskell/html/zeromq4-haskell.haddock

haddock-html:         /usr/share/doc/haskell-zeromq4-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
